Learn R Programming

gbRd (version 0.4.12)

Rdo_args2txt_list: Extract the descriptions of the arguments of a function

Description

Collect the descriptions of the arguments of a function in a named list with one element per argument.

Usage

Rdo_args2txt_list(x, arg, ...)

Value

A named list with one entry (a string) for each of the requested arguments.

Arguments

x

help object, may be any of the types that Rd_fun accepts: Rd object, name of a function, or the the value returned by help.

arg

A character vector naming the arguments to describe. If arg is missing, descriptions of all arguments are extracted.

...

additional arguments to pass to Rdo_args2txt

Author

Georgi N. Boshnakov

Details

If several arguments are described in a single documentation entry, then the whole text of the entry is given for each of the arguments.

See Also

Rdo_args2txt

Examples

Run this code
# each arg always gets an individual entry in the list;
# compare:
Rdo_args2txt_list("seq", c("from", "to", "by"))
# to:
cat(Rdo_args2txt("seq", c("from", "to", "by")))

Run the code above in your browser using DataLab