Basically, this function calls Rd_fun to get an Rd object
containing the required help sections, then converts them to text with
tools::Rd2txt. At this point however unwanted sections may be
present since tools::Rd2txt requires \title and \name.
If \title is not an element of keep_section, it should be
dropped. Other header information is dropped if omit_sec_header
= TRUE. The way this is done is crude and based on inspection. It
would be better done using the Rd object but then I might need to,
effectively reprogram Rd2txt.
FIXME: The above was done for version R-2.10 (I think), see if a more
modular version is available in current versions of R.
Also, it is tested only with help_type="text".
FIXME: Arguments whose description is marked "passed on to
Rd_fun" could be replaced by a "..." argument.