powered by
Collect the descriptions of the arguments of a function in a named list with one element per argument.
Rdo_args2txt_list(x, arg, ...)
A named list with one entry (a string) for each of the requested arguments.
help object, may be any of the types that Rd_fun accepts: Rd object, name of a function, or the the value returned by help.
Rd_fun
help
A character vector naming the arguments to describe. If arg is missing, descriptions of all arguments are extracted.
arg
additional arguments to pass to Rdo_args2txt
Rdo_args2txt
Georgi N. Boshnakov
If several arguments are described in a single documentation entry, then the whole text of the entry is given for each of the arguments.
# each arg always gets an individual entry in the list; # compare: Rdo_args2txt_list("seq", c("from", "to", "by")) # to: cat(Rdo_args2txt("seq", c("from", "to", "by")))
Run the code above in your browser using DataLab